REFSELR

Enum REFSELR 

pub enum REFSELR {
    INT1V2,
    INT1V8,
    INT2V4,
    VDD,
    AREF,
    _Reserved(u8),
}
Possible values of the field REFSEL

Variants



INT1V2

VREF = internal 1.2 V reference (VDD >= 1.7 V)



INT1V8

VREF = internal 1.8 V reference (VDD >= VREF + 0.2 V)



INT2V4

VREF = internal 2.4 V reference (VDD >= VREF + 0.2 V)



VDD

VREF = VDD



AREF

VREF = AREF (VDD >= VREF >= AREFMIN)



_Reserved(u8)

Reserved

Implementations

Source

impl REFSELR

pub fn bits(&self) -> u8

Value of the field as raw bits

pub fn is_int1v2(&self) -> bool

Checks if the value of the field is INT1V2

pub fn is_int1v8(&self) -> bool

Checks if the value of the field is INT1V8

pub fn is_int2v4(&self) -> bool

Checks if the value of the field is INT2V4

pub fn is_vdd(&self) -> bool

Checks if the value of the field is VDD

pub fn is_aref(&self) -> bool

Checks if the value of the field is AREF