pub enum REGION3WAR {
DISABLED,
ENABLED,
}Expand description
Possible values of the field REGION3WA
Variants
Implementations
Sourceimpl REGION3WAR
impl REGION3WAR
Sourcepub fn bit_is_clear(&self) -> bool
pub fn bit_is_clear(&self) -> bool
Returns true if the bit is clear (0)
Sourcepub fn bit_is_set(&self) -> bool
pub fn bit_is_set(&self) -> bool
Returns true if the bit is set (1)
Sourcepub fn is_disabled(&self) -> bool
pub fn is_disabled(&self) -> bool
Checks if the value of the field is DISABLED
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Checks if the value of the field is ENABLED