SAMPLEPERR

Enum SAMPLEPERR 

pub enum SAMPLEPERR {
    _128US,
    _256US,
    _512US,
    _1024US,
    _2048US,
    _4096US,
    _8192US,
    _16384US,
    _32MS,
    _65MS,
    _131MS,
    _Reserved(u8),
}
Possible values of the field SAMPLEPER

Variants



_128US

128 us



_256US

256 us



_512US

512 us



_1024US

1024 us



_2048US

2048 us



_4096US

4096 us



_8192US

8192 us



_16384US

16384 us



_32MS

32768 us



_65MS

65536 us



_131MS

131072 us



_Reserved(u8)

Reserved

Implementations

Source

impl SAMPLEPERR

pub fn bits(&self) -> u8

Value of the field as raw bits

pub fn is_128us(&self) -> bool

Checks if the value of the field is _128US

pub fn is_256us(&self) -> bool

Checks if the value of the field is _256US

pub fn is_512us(&self) -> bool

Checks if the value of the field is _512US

pub fn is_1024us(&self) -> bool

Checks if the value of the field is _1024US

pub fn is_2048us(&self) -> bool

Checks if the value of the field is _2048US

pub fn is_4096us(&self) -> bool

Checks if the value of the field is _4096US

pub fn is_8192us(&self) -> bool

Checks if the value of the field is _8192US

pub fn is_16384us(&self) -> bool

Checks if the value of the field is _16384US

pub fn is_32ms(&self) -> bool

Checks if the value of the field is _32MS

pub fn is_65ms(&self) -> bool

Checks if the value of the field is _65MS

pub fn is_131ms(&self) -> bool

Checks if the value of the field is _131MS