Module errorsrc

Module errorsrc 

Error source

Structs

R
Value read from the register
W
Value to write to the register
_BREAKW
Proxy
_FRAMINGW
Proxy
_OVERRUNW
Proxy
_PARITYW
Proxy

Enums

BREAKR
Possible values of the field BREAK
BREAKW
Values that can be written to the field BREAK
FRAMINGR
Possible values of the field FRAMING
FRAMINGW
Values that can be written to the field FRAMING
OVERRUNR
Possible values of the field OVERRUN
OVERRUNW
Values that can be written to the field OVERRUN
PARITYR
Possible values of the field PARITY
PARITYW
Values that can be written to the field PARITY